Computes equilibrium product margins and prices using the aggregative games technique described in Nocke and Schutz (2018). Assumes that firms are playing a Nash-Bertrand pricing game with either Logit or CES demand
# S4 method for Logit
calcMarginsAG(object, preMerger = TRUE, level = FALSE)# S4 method for CES
calcMarginsAG(object, preMerger = TRUE, level = FALSE)
# S4 method for Logit
calcPricesAG(object, preMerger = TRUE, isMax = FALSE, subset)
An instance of one of the classes listed above.
If TRUE, returns pre-merger outcome. If FALSE, returns post-merger outcome. Default is TRUE.
IF TRUE, return margins in dollars. If FALSE, returns margins in proportions. Default for most classes is FALSE.
If TRUE, a check is run to determine if the calculated equilibrium price vector locally maximizes profits. Default is FALSE.
A vector whose length equals the number of products where each element equals TRUE if the product indexed by that element should be included in the post-merger simulation and FALSE if it should be excluded. Default is a length k vector of TRUE.
Nocke, V. and Schutz, N. (2018), Multiproduct-Firm Oligopoly: An Aggregative Games Approach. Econometrica, 86: 523-557.tools:::Rd_expr_doi("10.3982/ECTA14720")/