Calculate the own and cross-price elasticity between any two products in the market.
# S4 method for Cournot
elast(object, preMerger = TRUE, market = FALSE)# S4 method for Linear
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for Logit
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for LogitBLP
elast(object, preMerger = TRUE, market = FALSE, partial = FALSE)
# S4 method for LogLin
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for AIDS
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for LogitNests
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for CES
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for CESNests
elast(object, preMerger = TRUE, market = FALSE)
# S4 method for VertBargBertLogit
elast(object, preMerger = TRUE, market = FALSE)
returns a k x k matrix of own- and cross-price elasticities, where k is the number of products in the market.
An instance of one of the classes listed above.
If TRUE, calculates pre-merger price elasticities. If FALSE, calculates post-merger price elasticities. Default is TRUE.
If TRUE, calculates the market (aggregate) elasticity. If FALSE, calculates matrix of own- and cross-price elasticities. Default is FALSE.
if TRUE returns the partial derivative rather than the elasticity. Default is FALSE
When ‘market’ is FALSE, this method computes the matrix of own and cross-price elasticities. Element i,j of this matrix is the percentage change in the demand for good i from a small change in the price of good j. When ‘market’ is TRUE, this method computes the market (aggregate) elasticities using share-weighted prices.
When ‘preMerger’ is TRUE, elasticities are calculated at pre-merger equilibrium prices and shares, and when ‘preMerger’ is FALSE, they are calculated at post-merger equilibrium prices and shares.